Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(401)

Unified Diff: sdk/lib/isolate/isolate.dart

Issue 70263002: Add RawReceivePort to dart2js. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments. Created 7 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/lib/isolate_patch.dart ('k') | tests/isolate/isolate.status » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/isolate/isolate.dart
diff --git a/sdk/lib/isolate/isolate.dart b/sdk/lib/isolate/isolate.dart
index 2774f5bc07c34a4d10164f64996b8b15de149709..d6f7bb795876b8c07ccaf622c14203470417bb5f 100644
--- a/sdk/lib/isolate/isolate.dart
+++ b/sdk/lib/isolate/isolate.dart
@@ -178,7 +178,7 @@ abstract class ReceivePort implements Stream {
void close();
/**
* Returns a send port that sends to this receive port.
*/
SendPort get sendPort;
}
@@ -206,6 +206,11 @@ abstract class RawReceivePort {
* After a call to this method any incoming message is silently dropped.
*/
void close();
+
+ /**
+ * Returns a [SendPort] that sends to this receive port.
+ */
+ SendPort get sendPort;
}
/**
« no previous file with comments | « sdk/lib/_internal/lib/isolate_patch.dart ('k') | tests/isolate/isolate.status » ('j') | no next file with comments »
@@ -178,7 +178,7 @@ abstract class ReceivePort implements Stream {
void close();
/**
- * Returns a send port that sends to this receive port.
+ * Returns a [SendPort] that sends to this receive port.
*/
SendPort get sendPort;

Powered by Google App Engine
This is Rietveld 408576698